==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSG_signature.h <==
/* $Date: 1997/08/21 07:17:30 $  $Author: kg $  $Revision: 1.4 $ */

/**************************************************************************/
/* FILE:             MSG_signature.h                                      */
/* Autor:            Andreas Kemper , Oliver Kluge                        */
/* Erstellt:         17/05/91                                             */
/* Letzte Aenderung: 16/10/95                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen zur Datei MSG_signature.c       */
/**************************************************************************/

#ifndef __MSG_signature__
#define __MSG_signature__


/**************************************************************************/
/* Konstanten und Makros                                                  */
/**************************************************************************/

#define MSG_key(s)	(MMMsignature(s))
#define MSG_sig(s)	MSGV_JumpTab[MMMtype(s)](s)


/**************************************************************************/
/* Prototypen                                                             */
/**************************************************************************/

void MSG_sig_int (		S_Pointer s );
void MSG_sig_domain (		S_Pointer s );
void MSG_sig_exec (		S_Pointer s );
void MSG_sig_string (		S_Pointer s );
void MSG_sig_list (		S_Pointer s );
void MSG_sig_category (		S_Pointer s );
void MSG_change_sig (		S_Pointer s, long num, long oldsig );
void MSG_sig_code (		S_Pointer s );
void MSG_sig_pari (		S_Pointer s );
void MSG_sig_ass_mem (		S_Pointer s );
void MSG_sig_point_array ( 	S_Pointer s );
void MSG_sig_array (            S_Pointer s );
void MSG_sig_general (		S_Pointer s );
void MSG_sig_hidden (		S_Pointer s );
void MSG_init ( 		VOID );


#endif /* __MSG_signature__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSG_signature.h <==
/* $Date: 1999/04/28 15:08:27 $  $Author: kg $  $Revision: 1.7 $ */

/**************************************************************************/
/* FILE:             MSG_signature.h                                      */
/* Autor:            Andreas Kemper , Oliver Kluge                        */
/* Erstellt:         17/05/91                                             */
/* Letzte Aenderung: 16/10/95                                             */
/*                                                                        */
/* Dieses File enthaelt die Deklarationen zur Datei MSG_signature.c       */
/**************************************************************************/

#ifndef __MSG_signature__
#define __MSG_signature__


/**************************************************************************/
/* Konstanten und Makros                                                  */
/**************************************************************************/

#define MSG_key(s)	(MMMsignature(s))
#define MSG_sig(s)	MSGV_JumpTab[MMMtype(s)](s)

extern void (*MSGV_JumpTab[MUPC_MaxStorTypes])(S_Pointer s);

/**************************************************************************/
/* Prototypen                                                             */
/**************************************************************************/

void MSG_sig_int (		S_Pointer s );
void MSG_sig_var (		S_Pointer s );
void MSG_sig_exec (		S_Pointer s );
void MSG_sig_string (		S_Pointer s );
void MSG_sig_list (		S_Pointer s );
void MSG_sig_category (		S_Pointer s );
void MSG_sig_code (		S_Pointer s );
void MSG_sig_pari (		S_Pointer s );
void MSG_sig_ass_mem (		S_Pointer s );
void MSG_sig_array (            S_Pointer s );
void MSG_sig_general (		S_Pointer s );
void MSG_sig_hidden (		S_Pointer s );
void MSG_sig_env (		S_Pointer s );
void MSG_sig_assoc (		S_Pointer s );

void MSG_change_sig (		S_Pointer s, long num, long oldsig );
void MSG_init ( 		 );


#endif /* __MSG_signature__ */
